{% extends "layout.jinja2" %}
{% from "security/_macros.html" import render_field_with_errors, render_field %}
{% block pagename %}
    Change Password
{% endblock %}

{% block body %}
{% include "security/_messages.html" %}
<h1>{{ _fsdomain('Change password') }}</h1>
<form action="{{ url_for_security('change_password') }}" method="POST" name="change_password_form">
  {{ change_password_form.hidden_tag() }}
  {% if active_password %}
    {{ render_field_with_errors(change_password_form.password) }}
  {% else %}
    <h3>{{  _fsdomain('You do not currently have a password - this will add one.') }}</h3>
  {% endif %}
  {{ render_field_with_errors(change_password_form.new_password) }}
  {{ render_field_with_errors(change_password_form.new_password_confirm) }}
  {{ render_field(change_password_form.submit) }}
</form>
{% endblock %}
